@@ -20,7 +20,6 @@ Contains the AddColumnDialog class
 
 from PyQt5.QtWidgets import QDialog, QFormLayout, QComboBox, QLineEdit
 from PyQt5.QtWidgets import QPushButton, QHBoxLayout, QVBoxLayout, QMessageBox
-import sys
 
 from .viewerRAT import NEWCOL_INT, NEWCOL_FLOAT, NEWCOL_STRING
 from .viewerstrings import MESSAGE_TITLE
@@ -75,10 +74,7 @@ class AddColumnDialog(QDialog):
     def getColumnType(self):
         index = self.typeCombo.currentIndex()
         userdata = self.typeCombo.itemData(index)
-        if sys.version_info[0] >= 3:
-            return int(userdata)
-        else:
-            return userdata.toInt()[0]
+        return int(userdata)
 
     def getColumnName(self):
         return str(self.nameEdit.text())
